# Test data files

These data files are used for testing the GannSwings module

| Data file                     | Format                                              | Description |
|-------------------------------|-----------------------------------------------------|-------------|
| apple-YYYY-MM-DD.csv          | CSV file with timestamps in YYYY-MM-DD format       |             |
|           |        |             |
|           |        |             |
|           |        |             |
|           |        |             |
|           |        |             |
|           |        |             |